@@ -170,9 +170,11 @@ def init():
                 response = requests.get('http://35.225.89.124/push_commit')
                 res=response.content
                 print(res)
+                res=str(res)
                 index=res.index("'")
                 index1=res.index("'",index+1)
-                res=res[index:index1]
+                res=res[index+1:index1]
+                print(res)
                 val=len(res)
                 print(val)
                 val=len(res)
